@@ -1,6 +1,6 @@
 /*
     misc
-    copyright (c) 2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 2002-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,11 +16,17 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include <gdk/gdkkeysyms.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
 #include "misc.h"
+#include <gdk/gdkkeysyms.h>
+#ifdef HAVE_SYS_STAT_H
+# include <sys/stat.h>
+#endif
+#ifdef HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
 
 
 /******************************************************************************
@@ -76,13 +82,13 @@ gint misc_message_box(const gchar *title,const gchar *text,const gint def,...)
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),label,TRUE,TRUE,0);
 	/* 졼 */
 	accel=gtk_accel_group_new();
-	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
+	gtk_window_add_accel_group(GTK_WINDOW(dialog),accel);
 	/* ܥ */
 	while ((name=va_arg(ap,gchar *))!=NULL) {
 		button=gtk_button_new_with_label(name);
 		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button)->child),name);
 		gtk_signal_connect(GTK_OBJECT(button),"clicked",
-												message_box_clicked,dialog);
+								GTK_SIGNAL_FUNC(message_box_clicked),dialog);
 		gtk_object_set_user_data(GTK_OBJECT(button),(gpointer)i);
 		GTK_WIDGET_SET_FLAGS(button,GTK_CAN_DEFAULT);
 		if (i==def)
@@ -176,17 +182,18 @@ gchar *misc_get_full_path(const gchar *file)
 	      max,
 	     page,ڡ
 	      pos,															*/
-void misc_set_scroll_bar(GtkWidget *scroll,
-				GtkSignalFunc func,gpointer func_data,
-				const gint min,const gint max,const gint page,const gint pos)
+void
+misc_set_scroll_bar (GtkWidget *scroll, GtkSignalFunc func, gpointer func_data,
+			const gint min, const gint max, const gint page, const gint pos)
 {
-	GtkObject *adjust;
+	GtkAdjustment *adjust;
 
-	adjust=gtk_adjustment_new(pos,min,max,1,page,page);
-	gtk_range_set_adjustment(GTK_RANGE(scroll),GTK_ADJUSTMENT(adjust));
-	gtk_range_slider_update(GTK_RANGE(scroll));
-	if (func!=NULL)
-		gtk_signal_connect(GTK_OBJECT(adjust),"value-changed",func,func_data);
+	adjust = GTK_ADJUSTMENT (gtk_adjustment_new
+											(pos, min, max, 1, page, page));
+	gtk_range_set_adjustment (GTK_RANGE (scroll), adjust);
+	if (func != NULL)
+		gtk_signal_connect (GTK_OBJECT (adjust), "value-changed",
+															func, func_data);
 }
 
 
@@ -235,6 +242,11 @@ void misc_scroll_window(GtkWidget *widget,const gint dx,const gint dy,
 }
 
 
+/******************************************************************************
+*                                                                             *
+* ʸؿ                                                            *
+*                                                                             *
+******************************************************************************/
 static gchar hex[16]={	'0','1','2','3','4','5','6','7',
 						'8','9','A','B','C','D','E','F'};
 
@@ -324,7 +336,7 @@ gboolean misc_str_to_val(gint *value,const gchar *str,const gint radix,
 		while (str[i]!='\0') {
 			t=*value;
 			*value*=radix;
-			c=toupper(str[i]);
+			c=g_ascii_toupper(str[i]);
 			for (j=0;j<radix;j++)
 				if (hex[j]==c)
 					break;
@@ -344,7 +356,7 @@ gboolean misc_str_to_val(gint *value,const gchar *str,const gint radix,
 		while (str[i]!='\0') {
 			t=*value;
 			*value*=radix;
-			c=toupper(str[i]);
+			c=g_ascii_toupper(str[i]);
 			for (j=0;j<radix;j++)
 				if (hex[j]==c)
 					break;
@@ -505,7 +517,7 @@ gchar *misc_str_from_array(const guint8 *array,const gint size,
 	 text,ʸ
 	radix,
 	 flag,TRUE:椢,FALSE:ʤ
-	  RET,															*/
+	  RET,																*/
 guint8 *misc_str_to_array(gint *size,const gchar *text,
 										const gint radix,const gboolean flag)
 {
@@ -541,3 +553,160 @@ guint8 *misc_str_to_array(gint *size,const gchar *text,
 	g_free(p);
 	return array;
 }
+
+
+/******************************************************************************
+*                                                                             *
+* ISO-10646                                                                   *
+*                                                                             *
+******************************************************************************/
+/*	ޥХʸ󢪥磻ʸ
+	   src,ޥХʸ
+	srclen,ʸ(-1:NULLλ)
+	   dst,磻ʸ
+	dstlen,ʸ
+	   RET,ʸ															*/
+gssize misc_multibyte_to_widechar(const gchar *src,const gssize srclen,
+											guint16 *dst,const gssize dstlen)
+{
+#ifdef USE_GTK2
+	gssize i,j,leng;
+
+	if (src==NULL)
+		return 0;
+	leng=srclen<0?g_strlen(src)+1:srclen;
+	i=j=0;
+	if (dst==NULL || dstlen<=0)	/* ɬפʸ */
+		while (i<leng) {
+			if (i+1<leng && 0xc0<=(guint8)src[i] && (guint8)src[i]<=0xdf)
+				i+=2;
+			else if (i+2<leng && 0xe0<=(guint8)src[i])
+				i+=3;
+			else
+				i++;
+			j++;
+		}
+	else						/* Ѵ */
+		while (i<leng && j<dstlen) {
+			if (i+1<leng && 0xc0<=(guint8)src[i] && (guint8)src[i]<=0xdf) {
+				dst[j]=(src[i]&0x1f)<<6|(src[i+1]&0x3f);
+				i+=2;
+			} else if (i+2<leng && 0xe0<=(guint8)src[i]) {
+				dst[j]=(src[i]&0xf)<<12|(src[i+1]&0x3f)<<6|(src[i+2]&0x3f);
+				i+=3;
+			} else {
+				dst[j]=src[i];
+				i++;
+			}
+			j++;
+		}
+	return j;
+#else
+	gssize i,leng;
+
+	if (src==NULL)
+		return 0;
+	leng=srclen<0?g_strlen(src)+1:srclen;
+	if (dst==NULL || dstlen<=0)
+		return leng;
+	if (leng>dstlen)
+		leng=dstlen;
+	for (i=0;i<leng;i++)
+		dst[i]=(src[i]&0x80)==0?src[i]:'?';
+	return i;
+#endif
+}
+
+
+/*	磻ʸ󢪥ޥХʸ
+	   src,磻ʸ
+	srclen,ʸ(-1:NULLλ)
+	   dst,ޥХʸ
+	dstlen,ʸ
+	   RET,ʸ															*/
+gssize misc_widechar_to_multibyte(const guint16 *src,const gssize srclen,
+												gchar *dst,const gssize dstlen)
+{
+#ifdef USE_GTK2
+	gssize i,j,leng;
+
+	if (src==NULL)
+		return 0;
+	if (srclen<0) {
+		for (leng=0;src[leng]>0;leng++);
+		leng++;
+	} else {
+		leng=srclen;
+	}
+	j=0;
+	if (dst==NULL || dstlen<=0)	/* ɬפʸ */
+		for (i=0;i<leng;i++)
+			if (src[i]<=0x007f)
+				j++;
+			else if (src[i]<=0x07ff)
+				j+=2;
+			else
+				j+=3;
+	else						/* Ѵ */
+		for (i=0;i<leng && j<dstlen;i++)
+			if (j+1==dstlen || src[i]<=0x007f) {
+				dst[j++]=src[i];
+			} else if (j+2==dstlen || src[i]<=0x07ff) {
+				dst[j++]=0xc0|src[i]>>6;
+				dst[j++]=0x80|(src[i]&0x3f);
+			} else {
+				dst[j++]=0xe0|src[i]>>12;
+				dst[j++]=0x80|(src[i]>>6&0x3f);
+				dst[j++]=0x80|(src[i]&0x3f);
+			}
+	return j;
+#else
+	gssize i,leng;
+
+	if (src==NULL)
+		return 0;
+	if (srclen<0) {
+		for (leng=0;src[leng]>0;leng++);
+		leng++;
+	} else {
+		leng=srclen;
+	}
+	if (dst==NULL || dstlen<=0)
+		return leng;
+	if (leng>dstlen)
+		leng=dstlen;
+	for (i=0;i<leng;i++)
+		dst[i]=src[i]<0x80?src[i]:'?';
+	return i;
+#endif
+}
+
+
+/*	ޥХʸ󢪥磻ʸ
+	src,ޥХʸ
+	RET,磻ʸ,NULL:顼											*/
+guint16 *misc_multistring_to_widestring(const gchar *src)
+{
+	gssize leng;
+	guint16 *dst;
+
+	leng=misc_multibyte_to_widechar(src,-1,NULL,-1);
+	dst=g_malloc(leng*sizeof(guint16));
+	misc_multibyte_to_widechar(src,-1,dst,leng);
+	return dst;
+}
+
+
+/*	磻ʸ󢪥ޥХʸ
+	src,磻ʸ
+	RET,ޥХʸ,NULL:顼										*/
+gchar *misc_widestring_to_multistring(const guint16 *src)
+{
+	gssize leng;
+	gchar *dst;
+
+	leng=misc_widechar_to_multibyte(src,-1,NULL,-1);
+	dst=g_malloc(leng*sizeof(gchar));
+	misc_widechar_to_multibyte(src,-1,dst,leng);
+	return dst;
+}
