@@ -88,9 +88,13 @@ void draw_caret(TmaidWindow *tmaid,GdkPoint *cursor)
 	gtk_widget_draw(tmaid->drawing,&rc);
 	if (timer_id==0)
 		timer_id=gtk_timeout_add(500,signal_timeout,NULL);
-	text=g_strdup_printf(tmaid->select.x<0
-						?_("%d,%d"):_("%d,%d  Selected(%d,%d)-(%d,%d)"),
-						x+1,y+1,tmaid->select.x+1,tmaid->select.y+1,x+1,y+1);
+	text = g_strdup_printf (_("L%d,C%d"), y + 1, x + 1);
+	gtk_label_set_text (GTK_LABEL (label_cursor), text);
+ 	g_free (text);
+	text = tmaid->select.x >= 0
+					? g_strdup_printf (_("Selected(L%d,C%d)-(L%d,C%d)"),
+						tmaid->select.y + 1, tmaid->select.x + 1, y + 1, x + 1)
+					: g_strdup ("");
 	context_id=gtk_statusbar_get_context_id(GTK_STATUSBAR(status),"Status");
 	gtk_statusbar_pop(GTK_STATUSBAR(status),context_id);
 	gtk_statusbar_push(GTK_STATUSBAR(status),context_id,text);
