@@ -65,6 +65,7 @@ GdkAtom atom_textmaid1;				/* ץ̿ѥȥ */
 GtkWidget *window;					/* ɥ */
 GtkWidget *notebook;				/* Ρȥ֥å */
 GtkWidget *status;					/* ơɥ */
+GtkWidget *label_cursor;			/* ɸ */
 GtkPositionType n_pos=GTK_POS_TOP;	/* Ρȥ֥åΰ */
 GtkItemFactory *item_factory_menu;	/* ˥塼 */
 GtkItemFactory *item_factory_popup;	/* ݥåץå */
@@ -103,7 +104,8 @@ int main(int argc,char *argv[])
 	GdkPixmap *pixmap;
 	GtkAccelGroup *accel_group;
 	GtkStyle *style;
-	GtkWidget *menubar,*toolbar,*text,*handle,*vbox,*sub_menu,*menu_item;
+	GtkWidget *menubar,*menu_item,*sub_menu;
+	GtkWidget *handle,*text,*table,*toolbar,*vbox,*frame;
 	GtkItemFactoryEntry menu_items[]={
 {N_("/_File"),                       NULL,         NULL,            0,"<Branch>"},
 {N_("/File/_New"),                   "<control>N", command_new,     0,"<Item>"},
@@ -483,8 +485,15 @@ int main(int argc,char *argv[])
 						gtk_pixmap_new(pixmap,mask),
 						toolbar_items[i].callback,toolbar_items[i].user_data);
 		}
+	/* ơ֥ */
+	table = gtk_table_new (1, 5, FALSE);
 	/* ơС */
 	status=gtk_statusbar_new();
+	/* ɸ */
+	label_cursor = gtk_label_new (NULL);
+	gtk_label_set_justify (GTK_LABEL (label_cursor), GTK_JUSTIFY_CENTER);
+	frame = gtk_frame_new(NULL);
+	gtk_container_add( GTK_CONTAINER (frame), label_cursor);
 	/* ƥ */
 	text=gtk_text_new(NULL,NULL);
 	gtk_signal_connect(GTK_OBJECT(text),"style-set",signal_style_set,NULL);
@@ -499,7 +508,11 @@ int main(int argc,char *argv[])
 	gtk_container_add(GTK_CONTAINER(handle),toolbar);
 	gtk_box_pack_start(GTK_BOX(vbox),handle,FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(vbox),notebook,TRUE,TRUE,0);
-	gtk_box_pack_end(GTK_BOX(vbox),status,FALSE,FALSE,0);
+	gtk_table_attach (GTK_TABLE (table), status, 0, 4, 0, 1,
+			GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+	gtk_table_attach (GTK_TABLE (table), frame, 4, 5, 0, 1,
+			GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+	gtk_box_pack_end(GTK_BOX(vbox),table,FALSE,FALSE,0);
 	gtk_box_pack_end(GTK_BOX(vbox),text,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(window),vbox);
 	/* ե */
