@@ -21,7 +21,6 @@
 
 
 #include "common.h"
-#include "intl.h"
 
 
 #define TMAID_VERSION_NOTICE "Text maid "VERSION" ("TMAID_BUILD_ENVIRONMENT")"
@@ -99,8 +98,10 @@ typedef struct TmaidWindow_Tag {
 	TmaidHistory *undo,*redo;	/* Խ */
 	GdkColor color[12];			/*  */
 	GdkFont *font;				/* ե */
+#ifdef USE_XIM
 	GdkIC *ic;					/* XIM */
 	GdkICAttr *ic_attr;			/* XIM° */
+#endif /* USE_XIM */
 	GdkPoint top;				/* ɥƬ */
 	GdkPoint cursor;			/* åȤΰ */
 	GdkPoint select;			/* 򳫻ϰ,-1:ʤ */
@@ -146,6 +147,7 @@ extern GdkAtom atom_textmaid1;			/* ץ̿ѥȥ */
 extern GtkWidget *window;				/* ɥ */
 extern GtkWidget *notebook;				/* Ρȥ֥å */
 extern GtkWidget *status;				/* ơɥ */
+extern GtkWidget *label_cursor;			/* ɸ */
 extern GtkPositionType n_pos;			/* Ρȥ֥åΰ */
 extern GtkItemFactory *item_factory_menu;	/* ˥塼 */
 extern GtkItemFactory *item_factory_popup;	/* ݥåץå */
